@@ -3,7 +3,7 @@ use warnings;
 
 package HTTP::Async;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Carp;
 use Data::Dumper;
@@ -650,7 +650,7 @@ sub _send_request {
     $args{PeerPort} ||= $uri->port;
 
     my $net_http_class = 'Net::HTTP::NB';
-    if ($uri->scheme and $uri->scheme eq 'https') {
+    if ($uri->scheme and $uri->scheme eq 'https' and not $request_is_to_proxy) {
         $net_http_class = 'Net::HTTPS::NB';
         eval {
             require Net::HTTPS::NB;
@@ -658,6 +658,15 @@ sub _send_request {
         };
         die "$net_http_class must be installed for https support" if $@;
     }
+    elsif($uri->scheme and $uri->scheme eq 'https' and $request_is_to_proxy) {
+        # We are making an HTTPS request through an HTTP proxy such as squid.
+        # The proxy will handle the HTTPS, we need to connect to it via HTTP
+        # and then make a request where the https is clear from the scheme...
+        $args{Host} = sprintf(
+            '%s:%s',
+            delete @args{'PeerAddr', 'PeerPort'}
+        );
+    }
     my $s = eval { $net_http_class->new(%args) };
 
     # We could not create a request - fake up a 503 response with
@@ -784,6 +793,8 @@ handle 304 responses.
 
 Naveed Massjouni for adding the https handling code.
 
+Alex Balhatchet for adding the https + proxy handling code.
+
 =head1 BUGS AND REPO
 
 Please submit all bugs, patches etc on github
